@@ -973,13 +973,13 @@ WITH t AS (
         a
     FROM
         y)
-    INSERT INTO y
-    SELECT
-        a + 20
-    FROM
-        t
-    RETURNING
-        *;
+INSERT INTO y
+SELECT
+    a + 20
+FROM
+    t
+RETURNING
+    *;
 
 SELECT
     *
@@ -2022,11 +2022,11 @@ WITH t1 AS (
     DELETE FROM bug6051
 RETURNING
     *)
-    INSERT INTO bug6051
-    SELECT
-        *
-    FROM
-        t1;
+INSERT INTO bug6051
+SELECT
+    *
+FROM
+    t1;
 
 SELECT
     *
@@ -2047,11 +2047,11 @@ WITH t1 AS (
     DELETE FROM bug6051
 RETURNING
     *)
-    INSERT INTO bug6051
-    SELECT
-        *
-    FROM
-        t1;
+INSERT INTO bug6051
+SELECT
+    *
+FROM
+    t1;
 
 SELECT
     *
@@ -2181,12 +2181,11 @@ INSERT INTO withz
         WHERE
             withz.k != EXCLUDED.k
         RETURNING
+            *)
+        SELECT
             *
-)
-    SELECT
-        *
-    FROM
-        aa;
+        FROM
+            aa;
 
 -- New query/snapshot demonstrates side-effects of previous query.
 SELECT
@@ -2306,8 +2305,7 @@ INSERT INTO withz
         VALUES (2, 'Blue')
     ON CONFLICT (k)
         DO UPDATE SET
-            (k,
-                v) = (
+            (k, v) = (
                 SELECT
                     k,
                     v
@@ -2322,8 +2320,7 @@ INSERT INTO withz
         VALUES (2, 'Red')
     ON CONFLICT (k)
         DO UPDATE SET
-            (k,
-                v) = (
+            (k, v) = (
                 SELECT
                     k,
                     v
